@@ -15,6 +15,19 @@ describe("es6-shim", function () {
 
 	myit("length property of the normalize method is 0.", function () {
 		assert("foo".normalize.length, 0, "length property of the normalize method is 0.");
+		assert(String.prototype.normalize.length, 0, "length property of the normalize method is 0.");
+	});
+
+	it("throws TypeError if `this` is null", function () {
+		assert.throws(function () {
+			String.prototype.normalize.call(null);
+		}, TypeError);
+	});
+	
+	it("throws TypeError if `this` is undefined", function () {
+		assert.throws(function () {
+			String.prototype.normalize.call(undefined);
+		}, TypeError);
 	});
 
 	myit("If f is not one of \"NFC\", \"NFD\", \"NFKC\", or \"NFKD\", then throw a RangeError Exception.", function () {
